"""Application context for Purrio CLI."""

from dataclasses import dataclass

from .client import HyperliquidClient
from .config import Config
from .output import OutputFormatter


@dataclass
class AppContext:
    """Shared application context passed between commands."""

    config: Config
    client: HyperliquidClient
    formatter: OutputFormatter
